@@ -20,7 +20,8 @@ except ImportError:  # pragma: no cover
 
 if VTK9:
 
-    from vtkmodules.vtkImagingHybrid import vtkSampleFunction
+    from vtkmodules.vtkImagingHybrid import (vtkSampleFunction,
+                                             vtkSurfaceReconstructionFilter)
     from vtkmodules.vtkInteractionWidgets import (vtkScalarBarWidget,
                                                   vtkSplineWidget,
                                                   vtkSphereWidget,
@@ -61,20 +62,18 @@ if VTK9:
                                           vtkOpenFOAMReader,
                                           vtkSTLWriter,
                                           vtkBYUReader,
+                                          vtkGLTFReader,
                                           vtkOBJReader)
     from vtkmodules.vtkIOImage import (vtkBMPReader,
                                        vtkDEMReader,
                                        vtkDICOMImageReader,
-                                       vtkDICOMImageReader,
-                                       vtkJPEGReader,
                                        vtkJPEGReader,
                                        vtkMetaImageReader,
                                        vtkNrrdReader,
-                                       vtkNrrdReader,
                                        vtkPNGReader,
                                        vtkPNMReader,
                                        vtkSLCReader,
-                                       vtkTIFFReader,
+                                       vtkHDRReader,
                                        vtkTIFFReader)
     from vtkmodules.vtkIOXML import (vtkXMLReader,
                                      vtkXMLWriter,
@@ -105,7 +104,6 @@ if VTK9:
                                         vtkRectilinearGridReader,
                                         vtkRectilinearGridWriter,
                                         vtkDataSetWriter,
-                                        vtkPolyDataReader,
                                         vtkDataSetReader)
     from vtkmodules.vtkCommonDataModel import (vtkImplicitFunction,
                                                vtkDataObject,
@@ -124,6 +122,7 @@ if VTK9:
                                                vtkDataSet,
                                                vtkPointLocator,
                                                vtkCellLocator,
+                                               vtkStaticCellLocator,
                                                vtkMultiBlockDataSet,
                                                vtkCompositeDataSet,
                                                vtkFieldData,
@@ -153,6 +152,7 @@ if VTK9:
                                                    vtkAnnotatedCubeActor,
                                                    vtkLegendBoxActor,
                                                    vtkCubeAxesActor)
+    from vtkmodules.vtkRenderingUI import vtkGenericRenderWindowInteractor
     from vtkmodules.vtkRenderingCore import (vtkTexture,
                                              vtkSkybox,
                                              vtkPropAssembly,
@@ -203,7 +203,8 @@ if VTK9:
                                                            vtkParametricSuperToroid,
                                                            vtkParametricTorus,
                                                            vtkParametricFunction,
-                                                           vtkParametricBohemianDome)
+                                                           vtkParametricBohemianDome,
+                                                           vtkKochanekSpline)
     from vtkmodules.vtkCommonCore import (VTK_COURIER,
                                           VTK_TIMES,
                                           VTK_ARIAL,
@@ -211,6 +212,10 @@ if VTK9:
                                           vtkIdTypeArray,
                                           vtkCharArray,
                                           vtkBitArray,
+                                          vtkFloatArray,
+                                          vtkTypeInt32Array,
+                                          vtkTypeInt64Array,
+                                          vtkSignedCharArray,
                                           vtkFileOutputWindow,
                                           vtkOutputWindow,
                                           vtkStringOutputWindow,
@@ -220,7 +225,6 @@ if VTK9:
                                           vtkTypeUInt32Array,
                                           vtkDataArray,
                                           vtkPoints,
-                                          vtkIdList,
                                           vtkLookupTable,
                                           VTK_UNSIGNED_CHAR,
                                           vtkAbstractArray,
@@ -261,8 +265,7 @@ if VTK9:
                                            vtkCellCenters,
                                            vtkConnectivityFilter,
                                            vtkCellDataToPointData,
-                                           vtkDelaunay3D,
-                                           vtkCutter)
+                                           vtkDelaunay3D)
     from vtkmodules.vtkFiltersGeneral import (vtkTableBasedClipDataSet,
                                               vtkTableToPolyData,
                                               vtkOBBTree,
@@ -271,14 +274,14 @@ if VTK9:
                                               vtkIntersectionPolyDataFilter,
                                               vtkCurvatures,
                                               vtkBoxClipDataSet,
-                                              vtkTableBasedClipDataSet,
                                               vtkWarpScalar,
                                               vtkWarpVector,
                                               vtkDataSetTriangleFilter,
                                               vtkGradientFilter,
                                               vtkShrinkFilter,
                                               vtkBooleanOperationPolyDataFilter,
-                                              vtkTransformFilter)
+                                              vtkTransformFilter,
+                                              vtkAxes)
     from vtkmodules.vtkFiltersModeling import (vtkOutlineFilter,
                                                vtkRibbonFilter,
                                                vtkLinearExtrusionFilter,
@@ -288,9 +291,10 @@ if VTK9:
                                                vtkLinearSubdivisionFilter,
                                                vtkButterflySubdivisionFilter,
                                                vtkLoopSubdivisionFilter,
+                                               vtkAdaptiveSubdivisionFilter,
+                                               vtkCollisionDetectionFilter,
                                                vtkSelectEnclosedPoints)
     from vtkmodules.vtkFiltersSources import (vtkOutlineCornerFilter,
-                                              vtkParametricFunctionSource,
                                               vtkParametricFunctionSource,
                                               vtkPlaneSource,
                                               vtkArcSource,
@@ -300,15 +304,11 @@ if VTK9:
                                               vtkArrowSource,
                                               vtkCylinderSource,
                                               vtkSphereSource,
-                                              vtkPlaneSource,
                                               vtkLineSource,
-                                              vtkCubeSource,
                                               vtkConeSource,
                                               vtkDiskSource,
                                               vtkRegularPolygonSource,
-                                              vtkLineSource,
                                               vtkPointSource,
-                                              vtkArrowSource,
                                               vtkFrustumSource)
     from vtkmodules.vtkFiltersGeometry import (vtkGeometryFilter,
                                                vtkStructuredGridGeometryFilter,
@@ -331,7 +331,7 @@ if VTK9:
                                            vtkImageDifference,
                                            vtkImageFlip,
                                            vtkRTAnalyticSource)
-    from vtkmodules.vtkFiltersFlowPaths import vtkStreamTracer
+    from vtkmodules.vtkFiltersFlowPaths import vtkEvenlySpacedStreamlines2D, vtkStreamTracer
     from vtkmodules.vtkCommonExecutionModel import vtkImageToStructuredGrid
     from vtkmodules.numpy_interface.dataset_adapter import (VTKObjectWrapper,
                                                             numpyTovtkDataArray,
@@ -426,4 +426,23 @@ else:  # pragma: no cover
     class vtkExplicitStructuredGrid():  # type: ignore
         """Empty placeholder for VTK9 compatibility."""
 
-        pass
+        def __init__(self):  # pragma: no cover
+            """Raise version error on init."""
+            from pyvista.core.errors import VTKVersionError
+            raise VTKVersionError('vtkHDRReader requires VTK v9 or newer')
+
+    class vtkHDRReader():   # type: ignore
+        """Empty placeholder for VTK9 compatibility."""
+
+        def __init__(self):  # pragma: no cover
+            """Raise version error on init."""
+            from pyvista.core.errors import VTKVersionError
+            raise VTKVersionError('vtkHDRReader requires VTK v9 or newer')
+
+    class vtkGLTFReader():   # type: ignore
+        """Empty placeholder for VTK9 compatibility."""
+
+        def __init__(self):  # pragma: no cover
+            """Raise version error on init."""
+            from pyvista.core.errors import VTKVersionError
+            raise VTKVersionError('vtkGLTFReader requires VTK v9 or newer')
