@@ -24,39 +24,51 @@ log.setLevel('CRITICAL')
 class MultiBlock(_vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject):
     """A composite class to hold many data sets which can be iterated over.
 
-    This wraps/extends the ``vtkMultiBlockDataSet`` class in VTK so that we can
-    easily plot these data sets and use the composite in a Pythonic manner.
+    This wraps/extends the ``vtkMultiBlockDataSet`` class in VTK so
+    that we can easily plot these data sets and use the composite in a
+    Pythonic manner.
 
-    You can think of ``MultiBlock`` like lists or dictionaries as we can
-    iterate over this data structure by index and we can also access blocks
-    by their string name.
+    You can think of ``MultiBlock`` like lists or dictionaries as we
+    can iterate over this data structure by index and we can also
+    access blocks by their string name.
 
     Examples
     --------
     >>> import pyvista as pv
 
-    >>> # Create empty composite dataset
+    Create empty composite dataset
+
     >>> blocks = pv.MultiBlock()
-    >>> # Add a dataset to the collection
+
+    Add a dataset to the collection.
+
     >>> sphere = pv.Sphere()
     >>> blocks.append(sphere)
-    >>> # Or add a named block
+
+    Add a named block.
+
     >>> blocks["cube"] = pv.Cube()
 
-    >>> # instantiate from a list of objects
-    >>> data = [pv.Sphere(), pv.Cube(), pv.Cone()]
-    >>> blocks = pv.MultiBlock(data)
+    Instantiate from a list of objects.
 
-    >>> # instantiate from a dictionary
-    >>> data = {"cube": pv.Cube(), "sphere": pv.Sphere()}
+    >>> data = [pv.Sphere(center=(2, 0, 0)), pv.Cube(center=(0, 2, 0)), 
+    ...         pv.Cone()]
     >>> blocks = pv.MultiBlock(data)
+    >>> blocks.plot()
+
+    Instantiate from a dictionary.
+
+    >>> data = {"cube": pv.Cube(), "sphere": pv.Sphere(center=(2, 2, 0))}
+    >>> blocks = pv.MultiBlock(data)
+    >>> blocks.plot()
+
+    Iterate over the collection
 
-    >>> # now iterate over the collection
     >>> for name in blocks.keys():
-    ...     block = blocks[name] # do something!
+    ...     block = blocks[name]
 
     >>> for block in blocks:
-    ...     surf = block.extract_surface() # Do something with each dataset
+    ...     surf = block.extract_surface()  # Do something with each dataset
 
     """
 
@@ -108,7 +120,6 @@ class MultiBlock(_vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject):
             block = self.GetBlock(i)
             if not is_pyvista_dataset(block):
                 self.SetBlock(i, pyvista.wrap(block))
-        return
 
     @property
     def bounds(self) -> List[float]:
@@ -116,43 +127,76 @@ class MultiBlock(_vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject):
 
         Returns
         -------
-        tuple(float):
+        tuple(float)
             length 6 tuple of floats containing min/max along each axis
 
+        Examples
+        --------
+        Return the bounds across blocks.
+
+        >>> import pyvista as pv
+        >>> data = [pv.Sphere(center=(2, 0, 0)), pv.Cube(center=(0, 2, 0)), pv.Cone()]
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.bounds
+        [-0.5, 2.5, -0.5, 2.5, -0.5, 0.5]
+
         """
-        bounds = [np.inf,-np.inf, np.inf,-np.inf, np.inf,-np.inf]
+        # apply reduction of min and max over each block
+        all_bounds = [block.bounds for block in self if block]
+        # edge case where block has no bounds
+        if not all_bounds:  # pragma: no cover
+            minima = np.array([0, 0, 0])
+            maxima = np.array([0, 0, 0])
+        else:
+            minima = np.minimum.reduce(all_bounds)[::2]
+            maxima = np.maximum.reduce(all_bounds)[1::2]
 
-        def update_bounds(ax, nb, bounds):
-            """Update bounds while keeping track (internal helper)."""
-            if nb[2*ax] < bounds[2*ax]:
-                bounds[2*ax] = nb[2*ax]
-            if nb[2*ax+1] > bounds[2*ax+1]:
-                bounds[2*ax+1] = nb[2*ax+1]
-            return bounds
-
-        # get bounds for each block and update
-        for i in range(self.n_blocks):
-            if self[i] is None:
-                continue
-            bnds = self[i].bounds  # type: ignore
-            for a in range(3):
-                bounds = update_bounds(a, bnds, bounds)
-
-        return bounds
+        # interleave minima and maxima for bounds
+        return np.stack([minima, maxima]).ravel('F').tolist()
 
     @property
     def center(self) -> Any:
-        """Return the center of the bounding box."""
-        return np.array(self.bounds).reshape(3,2).mean(axis=1)
+        """Return the center of the bounding box.
+
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = [pv.Sphere(center=(2, 0, 0)), pv.Cube(center=(0, 2, 0)), pv.Cone()]
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.center  # doctest:+SKIP
+        array([1., 1., 0.])
+
+        """
+        return np.reshape(self.bounds, (3, 2)).mean(axis=1)
 
     @property
     def length(self) -> float:
-        """Return the length of the diagonal of the bounding box."""
+        """Return the length of the diagonal of the bounding box.
+
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = [pv.Sphere(center=(2, 0, 0)), pv.Cube(center=(0, 2, 0)), pv.Cone()]
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.length
+        4.3584
+
+        """
         return pyvista.Box(self.bounds).length
 
     @property
     def n_blocks(self) -> int:
-        """Return the total number of blocks set."""
+        """Return the total number of blocks set.
+
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = [pv.Sphere(center=(2, 0, 0)), pv.Cube(center=(0, 2, 0)), pv.Cone()]
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.n_blocks
+        3
+
+        """
         return self.GetNumberOfBlocks()
 
     @n_blocks.setter
@@ -167,19 +211,34 @@ class MultiBlock(_vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject):
 
         Returns
         -------
-        volume : float
+        float
             Total volume of the mesh.
 
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = [pv.Sphere(center=(2, 0, 0)), pv.Cube(center=(0, 2, 0)), pv.Cone()]
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.volume
+        1.7348
+
         """
-        volume = 0.0
-        for block in self:
-            if block is None:
-                continue
-            volume += block.volume
-        return volume
+        return sum(block.volume for block in self if block)
 
     def get_data_range(self, name: str) -> Tuple[float, float]:  # type: ignore
-        """Get the min/max of an array given its name across all blocks."""
+        """Get the min/max of an array given its name across all blocks.
+
+        Parameters
+        ----------
+        name : str
+            Name of the array.
+
+        Returns
+        -------
+        tuple
+            ``(min, max)`` of the named array.
+
+        """
         mini, maxi = np.inf, -np.inf
         for i in range(self.n_blocks):
             data = self[i]
@@ -194,7 +253,27 @@ class MultiBlock(_vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject):
         return mini, maxi
 
     def get_index_by_name(self, name: str) -> int:
-        """Find the index number by block name."""
+        """Find the index number by block name.
+
+        Parameters
+        ----------
+        name : str
+            Name of the block.
+
+        Returns
+        -------
+        int
+            Index of the block.
+
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = {"cube": pv.Cube(), "sphere": pv.Sphere(center=(2, 2, 0))}
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.get_index_by_name('sphere')
+        1
+
+        """
         for i in range(self.n_blocks):
             if self.get_block_name(i) == name:
                 return i
@@ -235,40 +314,118 @@ class MultiBlock(_vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject):
             self.refs.append(data)
         return data
 
-    def append(self, data: DataSet):
-        """Add a data set to the next block index."""
+    def append(self, dataset: DataSet):
+        """Add a data set to the next block index.
+
+        Parameters
+        ----------
+        dataset : pyvista.DataSet
+            Dataset to append to this multi-block.
+
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = {"cube": pv.Cube(), "sphere": pv.Sphere(center=(2, 2, 0))}
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.append(pv.Cone())
+        >>> len(blocks)
+        3
+
+        """
         index = self.n_blocks  # note off by one so use as index
-        self[index] = data
-        self.refs.append(data)
+        self[index] = dataset
+        self.refs.append(dataset)
 
     def get(self, index: Union[int, str]) -> Optional['MultiBlock']:
         """Get a block by its index or name.
 
         If the name is non-unique then returns the first occurrence.
 
+        Parameters
+        ----------
+        index : int or str
+            Index or name of the dataset within the multiblock.
+
+        Returns
+        -------
+        pyvista.DataSet
+            Dataset from the given index.
+
         """
         return self[index]
 
     def set_block_name(self, index: int, name: str):
-        """Set a block's string name at the specified index."""
+        """Set a block's string name at the specified index.
+
+        Parameters
+        ----------
+        index : int
+            Index or the dataset within the multiblock.
+
+        name : str
+            Name to assign to the block at ``index``.
+
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = {"cube": pv.Cube(), "sphere": pv.Sphere(center=(2, 2, 0))}
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.append(pv.Cone())
+        >>> blocks.set_block_name(2, 'cone')
+        >>> blocks.keys()
+        ['cube', 'sphere', 'cone']
+
+        """
         if name is None:
             return
         self.GetMetaData(index).Set(_vtk.vtkCompositeDataSet.NAME(), name)
         self.Modified()
 
     def get_block_name(self, index: int) -> Optional[str]:
-        """Return the string name of the block at the given index."""
+        """Return the string name of the block at the given index.
+
+        Parameters
+        ----------
+        index : int
+            Index of the block to get the name of.
+
+        Returns
+        -------
+        str
+            Name of the block at the given index.
+
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = {"cube": pv.Cube(), "sphere": pv.Sphere(center=(2, 2, 0))}
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.get_block_name(0)
+        'cube'
+
+        """
         meta = self.GetMetaData(index)
         if meta is not None:
             return meta.Get(_vtk.vtkCompositeDataSet.NAME())
         return None
 
     def keys(self) -> List[Optional[str]]:
-        """Get all the block names in the dataset."""
-        names = []
-        for i in range(self.n_blocks):
-            names.append(self.get_block_name(i))
-        return names
+        """Get all the block names in the dataset.
+
+        Returns
+        -------
+        list
+            List of block names.
+
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = {"cube": pv.Cube(), "sphere": pv.Sphere(center=(2, 2, 0))}
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.keys()
+        ['cube', 'sphere']
+
+        """
+        return [self.get_block_name(i) for i in range(self.n_blocks)]
 
     def _ipython_key_completions_(self) -> List[Optional[str]]:
         return self.keys()
@@ -337,7 +494,19 @@ class MultiBlock(_vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject):
     __next__ = next
 
     def pop(self, index: Union[int, str]) -> Optional['MultiBlock']:
-        """Pop off a block at the specified index."""
+        """Pop off a block at the specified index.
+
+        Parameters
+        ----------
+        index : int or str
+            Index or name of the dataset within the multiblock.
+
+        Returns
+        -------
+        pyvista.DataSet
+            Dataset from the given index.
+
+        """
         data = self[index]
         del self[index]
         return data
@@ -346,10 +515,19 @@ class MultiBlock(_vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject):
         """Remove any null blocks in place.
 
         Parameters
-        -----------
+        ----------
         empty : bool
             Remove any meshes that are empty as well (have zero points).
 
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = {"cube": pv.Cube(), "empty": pv.PolyData()}
+        >>> blocks = pv.MultiBlock(data)
+        >>> blocks.clean(empty=True)
+        >>> blocks.keys()
+        ['cube']
+
         """
         null_blocks = []
         for i in range(self.n_blocks):
@@ -368,7 +546,6 @@ class MultiBlock(_vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject):
             # Cast as int because windows is super annoying
             del self[int(null_blocks[i])]
             null_blocks -= 1
-        return
 
     def _get_attrs(self):
         """Return the representation methods (internal helper)."""
@@ -444,17 +621,26 @@ class MultiBlock(_vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject):
         pass
 
     def copy(self, deep=True):
-        """Return a copy of the object.
+        """Return a copy of the multiblock.
 
         Parameters
         ----------
         deep : bool, optional
-            When True makes a full copy of the object.
+            When ``True``, make a full copy of the object.
 
         Returns
         -------
-        newobject : same as input
-           Deep or shallow copy of the input.
+        pyvista.MultiBlock
+           Deep or shallow copy of the ``MultiBlock``.
+
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> data = [pv.Sphere(center=(2, 0, 0)), pv.Cube(center=(0, 2, 0)), pv.Cone()]
+        >>> blocks = pv.MultiBlock(data)
+        >>> new_blocks = blocks.copy()
+        >>> len(new_blocks)
+        3
 
         """
         thistype = type(self)
