@@ -47,7 +47,7 @@ class Grid(DataSet):
 
 
 class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
-    """Extend the functionality of a vtk.vtkRectilinearGrid object.
+    """Dataset with variable spacing in the three coordinate directions.
 
     Can be initialized in several ways:
 
@@ -64,20 +64,22 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
     >>> import vtk
     >>> import numpy as np
 
-    >>> # Create empty grid
+    Create an empty grid
+
     >>> grid = pyvista.RectilinearGrid()
 
-    >>> # Initialize from a vtk.vtkRectilinearGrid object
+    Initialize from a vtk.vtkRectilinearGrid object
+
     >>> vtkgrid = vtk.vtkRectilinearGrid()
     >>> grid = pyvista.RectilinearGrid(vtkgrid)
 
-    >>> # Create from NumPy arrays
+    Create from NumPy arrays
+
     >>> xrng = np.arange(-10, 10, 2)
     >>> yrng = np.arange(-10, 10, 5)
     >>> zrng = np.arange(-10, 10, 1)
     >>> grid = pyvista.RectilinearGrid(xrng, yrng, zrng)
 
-
     """
 
     _WRITERS = {'.vtk': _vtk.vtkRectilinearGridWriter,
@@ -227,10 +229,18 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
     @Grid.dimensions.setter  # type: ignore
     def dimensions(self, dims):
         """Do not let the dimensions of the RectilinearGrid be set."""
-        raise AttributeError("The dimensions of a `RectilinearGrid` are implicitly defined and thus cannot be set.")
+        raise AttributeError("The dimensions of a `RectilinearGrid` are implicitly "
+                             "defined and thus cannot be set.")
 
     def cast_to_structured_grid(self):
-        """Cast this rectilinear grid to a :class:`pyvista.StructuredGrid`."""
+        """Cast this rectilinear grid to a structured grid.
+
+        Returns
+        -------
+        pyvista.StructuredGrid
+            This grid as a structured grid.
+
+        """
         alg = _vtk.vtkRectilinearGridToPointSet()
         alg.SetInputData(self)
         alg.Update()
@@ -238,7 +248,7 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
 
 
 class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
-    """Extend the functionality of a vtk.vtkImageData object.
+    """Models datasets with uniform spacing in the three coordinate directions.
 
     Can be initialized in several ways:
 
@@ -313,7 +323,7 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         """Return the default str representation."""
         return DataSet.__str__(self)
 
-    def _from_specs(self, dims, spacing=(1.0,1.0,1.0), origin=(0.0, 0.0, 0.0)):
+    def _from_specs(self, dims, spacing=(1.0, 1.0, 1.0), origin=(0.0, 0.0, 0.0)):
         """Create VTK image data directly from numpy arrays.
 
         A uniform grid is defined by the node spacings for each axis
@@ -421,14 +431,28 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         return attrs
 
     def cast_to_structured_grid(self):
-        """Cast this uniform grid to a :class:`pyvista.StructuredGrid`."""
+        """Cast this uniform grid to a structured grid.
+
+        Returns
+        -------
+        pyvista.StructuredGrid
+            This grid as a structured grid.
+
+        """
         alg = _vtk.vtkImageToStructuredGrid()
         alg.SetInputData(self)
         alg.Update()
         return _get_output(alg)
 
     def cast_to_rectilinear_grid(self):
-        """Cast this uniform grid to a :class:`pyvista.RectilinearGrid`."""
+        """Cast this uniform grid to a rectilinear grid.
+
+        Returns
+        -------
+        pyvista.RectilinearGrid
+            This uniform grid as a rectilinear grid.
+
+        """
         def gen_coords(i):
             coords = np.cumsum(np.insert(np.full(self.dimensions[i] - 1,
                                                  self.spacing[i]), 0, 0)
@@ -438,8 +462,8 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         ycoords = gen_coords(1)
         zcoords = gen_coords(2)
         grid = pyvista.RectilinearGrid(xcoords, ycoords, zcoords)
-        grid.point_arrays.update(self.point_arrays)
-        grid.cell_arrays.update(self.cell_arrays)
-        grid.field_arrays.update(self.field_arrays)
+        grid.point_data.update(self.point_data)
+        grid.cell_data.update(self.cell_data)
+        grid.field_data.update(self.field_data)
         grid.copy_meta_from(self)
         return grid
