@@ -20,7 +20,14 @@ class PickingHelper:
     picked_horizon = None
 
     def get_pick_position(self):
-        """Get the pick position/area as x0, y0, x1, y1."""
+        """Get the pick position or area.
+
+        Returns
+        -------
+        sequence
+            Picked position or area as ``(x0, y0, x1, y1)``.
+
+        """
         return self.renderer.get_pick_position()
 
     def enable_cell_picking(self, mesh=None, callback=None, through=True,
@@ -40,11 +47,10 @@ class PickingHelper:
 
         Uses last input mesh for input by default.
 
-        Warning
-        -------
-        Visible cell picking (``through=False``) will only work if the
-        mesh is displayed with a ``'surface'`` representation style
-        (the default).
+        .. warning::
+           Visible cell picking (``through=False``) will only work if
+           the mesh is displayed with a ``'surface'`` representation
+           style (the default).
 
         Parameters
         ----------
@@ -70,6 +76,10 @@ class PickingHelper:
         show : bool
             Show the selection interactively.
 
+        show_message : bool or str, optional
+            Show the message about how to use the cell picking tool. If this
+            is a string, that will be the message shown.
+
         style : str
             Visualization style of the selection.  One of the
             following: ``style='surface'``, ``style='wireframe'``, or
@@ -81,17 +91,13 @@ class PickingHelper:
         color : str, optional
             The color of the selected mesh is shown.
 
-        show_message : bool or str, optional
-            Show the message about how to use the cell picking tool. If this
-            is a string, that will be the message shown.
-
         font_size : int, optional
             Sets the font size of the message.
 
         start : bool, optional
             Automatically start the cell selection tool.
 
-        kwargs : optional
+        **kwargs : dict, optional
             All remaining keyword arguments are used to control how
             the selection is interactively displayed.
 
@@ -153,7 +159,7 @@ class PickingHelper:
 
         def through_pick_call_back(picker, event_id):
             extract = _vtk.vtkExtractGeometry()
-            mesh.cell_arrays['orig_extract_id'] = np.arange(mesh.n_cells)
+            mesh.cell_data['orig_extract_id'] = np.arange(mesh.n_cells)
             extract.SetInputData(mesh)
             extract.SetImplicitFunction(picker.GetFrustum())
             extract.Update()
@@ -221,8 +227,6 @@ class PickingHelper:
         if start:
             self.iren._style_class.StartSelect()
 
-        return
-
     def enable_point_picking(self, callback=None, show_message=True,
                              font_size=18, color='pink', point_size=10,
                              use_mesh=False, show_point=True, tolerance=0.025,
@@ -238,18 +242,13 @@ class PickingHelper:
 
         Parameters
         ----------
-        callback : function, optional
+        callback : callable, optional
             When input, calls this function after a pick is made.  The
             picked point is input as the first parameter to this
             function.  If ``use_mesh`` is ``True``, the callback
             function will be passed a pointer to the picked mesh and
             the point ID of the selected mesh.
 
-        use_mesh : bool, optional
-            If ``True``, the callback function will be passed a
-            pointer to the picked mesh and the point ID of the
-            selected mesh.
-
         show_message : bool or str, optional
             Show the message about how to use the point picking
             tool. If this is a string, that will be the message shown.
@@ -257,21 +256,29 @@ class PickingHelper:
         font_size : int, optional
             Sets the size of the message.
 
+        color : str, optional
+            The color of the selected mesh is shown.
+
         point_size : int, optional
             Size of picked points if ``show_point`` is
             ``True``. Default 10.
 
-        color : str, optional
-            The color of the selected mesh is shown.
+        use_mesh : bool, optional
+            If ``True``, the callback function will be passed a
+            pointer to the picked mesh and the point ID of the
+            selected mesh.
+
+        show_point : bool, optional
+            Show the picked point after clicking.
 
         tolerance : float, optional
             Specify tolerance for performing pick operation. Tolerance
             is specified as fraction of rendering window
-            size. (Rendering window size is measured across diagonal.)
+            size. Rendering window size is measured across diagonal.
 
-        kwargs : optional, optional
+        **kwargs : dict, optional
             All remaining keyword arguments are used to control how
-            the picked point is interactively displayed
+            the picked point is interactively displayed.
 
         """
 
@@ -283,7 +290,7 @@ class PickingHelper:
                 self.add_mesh(self.picked_point, color=color,
                               point_size=point_size, name='_picked_point',
                               pickable=False, reset_camera=False, **kwargs)
-            if hasattr(callback, '__call__'):
+            if callable(callback):
                 if use_mesh:
                     try_callback(callback, self.picked_mesh, self.picked_point_id)
                 else:
@@ -304,24 +311,22 @@ class PickingHelper:
             self.add_text(str(show_message), font_size=font_size,
                           name='_point_picking_message')
 
-        return
-
     def enable_path_picking(self, callback=None, show_message=True,
                             font_size=18, color='pink', point_size=10,
                             line_width=5, show_path=True, tolerance=0.025,
                             **kwargs):
         """Enable picking at paths.
 
-        This is a convenience method for ``enable_point_picking`` to
-        keep track of the picked points and create a line using those
-        points.
+        This is a convenience method for :func:`enable_point_picking
+        <PickingHelper.enable_point_picking>` to keep track of the
+        picked points and create a line using those points.
 
         The line is saved to the ``.picked_path`` attribute of this
         plotter
 
         Parameters
         ----------
-        callback : callable
+        callback : callable, optional
             When given, calls this function after a pick is made.  The
             entire picked path is passed as the only parameter to this
             function.
@@ -330,31 +335,31 @@ class PickingHelper:
             Show the message about how to use the point picking
             tool. If this is a string, that will be the message shown.
 
-        show_path : bool, optional
-            Show the picked path interactively
-
         font_size : int, optional
             Sets the size of the message.
 
+        color : str, optional
+            The color of the selected mesh is shown.
+
         point_size : int, optional
             Size of picked points if ``show_path`` is
             ``True``. Default 10.
 
-        color : str, optional
-            The color of the selected mesh is shown.
-
         line_width : float, optional
             Thickness of path representation if ``show_path`` is
             ``True``.  Default 5.
 
+        show_path : bool, optional
+            Show the picked path interactively.
+
         tolerance : float, optional
             Specify tolerance for performing pick operation. Tolerance
             is specified as fraction of rendering window
             size.  Rendering window size is measured across diagonal.
 
-        kwargs : optional
+        **kwargs : dict, optional
             All remaining keyword arguments are used to control how
-            the picked path is interactively displayed
+            the picked path is interactively displayed.
 
         """
         kwargs.setdefault('pickable', False)
@@ -381,28 +386,28 @@ class PickingHelper:
                 self.add_mesh(self.picked_path, color=color, name='_picked_path',
                               line_width=line_width, point_size=point_size,
                               reset_camera=False, **kwargs)
-            if hasattr(callback, '__call__'):
+            if callable(callback):
                 try_callback(callback, self.picked_path)
-            return
 
         def _clear_path_event_watcher():
             del the_points[:]
             del the_ids[:]
             self.remove_actor('_picked_path')
-            return
 
         self.add_key_event('c', _clear_path_event_watcher)
         if show_message is True:
             show_message = "Press P to pick under the mouse\nPress C to clear"
 
-        return self.enable_point_picking(callback=_the_callback, use_mesh=True,
-                font_size=font_size, show_message=show_message,
-                show_point=False, tolerance=tolerance)
+        self.enable_point_picking(callback=_the_callback,
+                                  use_mesh=True, font_size=font_size,
+                                  show_message=show_message,
+                                  show_point=False,
+                                  tolerance=tolerance)
 
     def enable_geodesic_picking(self, callback=None, show_message=True,
                                 font_size=18, color='pink', point_size=10,
                                 line_width=5, tolerance=0.025, show_path=True,
-                                **kwargs):
+                                keep_order=True, **kwargs):
         """Enable picking at geodesic paths.
 
         This is a convenience method for ``enable_point_picking`` to
@@ -410,7 +415,7 @@ class PickingHelper:
         using those points.
 
         The geodesic path is saved to the ``.picked_geodesic``
-        attribute of this plotter
+        attribute of this plotter.
 
         Parameters
         ----------
@@ -419,9 +424,6 @@ class PickingHelper:
             entire picked, geodesic path is passed as the only
             parameter to this function.
 
-        show_path : bool, optional
-            Show the picked path interactively
-
         show_message : bool or str, optional
             Show the message about how to use the point picking
             tool. If this is a string, that will be the message shown.
@@ -429,25 +431,41 @@ class PickingHelper:
         font_size : int, optional
             Sets the size of the message.
 
+        color : str, optional
+            The color of the selected mesh is shown.
+
         point_size : int, optional
             Size of picked points if ``show_path`` is
             ``True``. Default 10.
 
-        color : str, optional
-            The color of the selected mesh is shown.
-
         line_width : float, optional
             Thickness of path representation if ``show_path`` is
             ``True``.  Default 5.
 
-        tolerance : float
+        tolerance : float, optional
             Specify tolerance for performing pick operation. Tolerance
             is specified as fraction of rendering window
             size.  Rendering window size is measured across diagonal.
 
-        kwargs : optional
+        show_path : bool, optional
+            Show the picked path interactively.
+
+        keep_order : bool, optional
+            If ``True``, the created geodesic path is a single ordered
+            and cleaned line from the first point to the last.
+
+            .. note::
+
+                In older versions there were apparent discontinuities
+                in the resulting path due to the behavior of the
+                underlying VTK filter which corresponds to
+                ``keep_order=False``.
+
+            .. versionadded:: 0.32.0
+
+        **kwargs : dict, optional
             All remaining keyword arguments are used to control how
-            the picked path is interactively displayed
+            the picked path is interactively displayed.
 
         """
         kwargs.setdefault('pickable', False)
@@ -461,6 +479,7 @@ class PickingHelper:
             point = mesh.points[idx]
             if self._last_picked_idx is None:
                 self.picked_geodesic = pyvista.PolyData(point)
+                self.picked_geodesic['vtkOriginalPointIds'] = [idx]
             else:
                 surface = mesh.extract_surface().triangulate()
                 locator = _vtk.vtkPointLocator()
@@ -468,30 +487,36 @@ class PickingHelper:
                 locator.BuildLocator()
                 start_idx = locator.FindClosestPoint(mesh.points[self._last_picked_idx])
                 end_idx = locator.FindClosestPoint(point)
-                self.picked_geodesic = self.picked_geodesic + surface.geodesic(start_idx, end_idx)
+                self.picked_geodesic += surface.geodesic(start_idx, end_idx,
+                                                         keep_order=keep_order)
+                if keep_order:
+                    # it makes sense to remove adjacent duplicate points
+                    self.picked_geodesic.clean(inplace=True, lines_to_points=False,
+                                               polys_to_lines=False,
+                                               strips_to_polys=False)
             self._last_picked_idx = idx
 
             if show_path:
                 self.add_mesh(self.picked_geodesic, color=color, name='_picked_path',
                               line_width=line_width, point_size=point_size,
                               reset_camera=False, **kwargs)
-            if hasattr(callback, '__call__'):
+            if callable(callback):
                 try_callback(callback, self.picked_geodesic)
-            return
 
         def _clear_g_path_event_watcher():
             self.picked_geodesic = pyvista.PolyData()
             self.remove_actor('_picked_path')
             self._last_picked_idx = None
-            return
 
         self.add_key_event('c', _clear_g_path_event_watcher)
         if show_message is True:
             show_message = "Press P to pick under the mouse\nPress C to clear"
 
-        return self.enable_point_picking(callback=_the_callback, use_mesh=True,
-                font_size=font_size, show_message=show_message,
-                tolerance=tolerance, show_point=False)
+        self.enable_point_picking(callback=_the_callback,
+                                  use_mesh=True, font_size=font_size,
+                                  show_message=show_message,
+                                  tolerance=tolerance,
+                                  show_point=False)
 
     def enable_horizon_picking(self, callback=None, normal=(0,0,1),
                                width=None, show_message=True,
@@ -512,20 +537,13 @@ class PickingHelper:
             function.
 
         normal : tuple(float), optional
-            The normal to the horizon surface's projection plane
+            The normal to the horizon surface's projection plane.
 
         width : float, optional
             The width of the horizon surface. Default behaviour will
             dynamically change the surface width depending on its
             length.
 
-        show_horizon : bool, optional
-            Show the picked horizon surface interactively.
-
-        show_path : bool, optional
-            Show the picked path that the horizon is built from
-            interactively.
-
         show_message : bool or str, optional
             Show the message about how to use the horizon picking
             tool. If this is a string, that will be the message shown.
@@ -533,28 +551,30 @@ class PickingHelper:
         font_size : int, optional
             Sets the font size of the message.
 
+        color : str, optional
+            The color of the horizon surface if shown.
+
         point_size : int, optional
             Size of picked points if ``show_horizon`` is
             ``True``. Default 10.
 
-        color : str, optional
-            The color of the horizon surface if shown.
-
         line_width : float, optional
             Thickness of path representation if ``show_horizon`` is
             ``True``.  Default 5.
 
+        show_path : bool, optional
+            Show the picked path that the horizon is built from
+            interactively.
+
         opacity : float, optional
             The opacity of the horizon surface if shown.
 
-        tolerance : float, optional
-            Specify tolerance for performing pick operation. Tolerance
-            is specified as fraction of rendering window
-            size. Rendering window size is measured across diagonal.
+        show_horizon : bool, optional
+            Show the picked horizon surface interactively.
 
-        kwargs : optional
+        **kwargs : dict, optional
             All remaining keyword arguments are used to control how
-            the picked path is interactively displayed
+            the picked path is interactively displayed.
 
         """
         name = '_horizon'
@@ -571,7 +591,7 @@ class PickingHelper:
                               opacity=opacity, pickable=False,
                               reset_camera=False)
 
-            if hasattr(callback, '__call__'):
+            if callable(callback):
                 try_callback(callback, path)
 
         self.enable_path_picking(callback=_the_callback,
@@ -580,7 +600,14 @@ class PickingHelper:
             **kwargs)
 
     def pick_click_position(self):
-        """Get corresponding click location in the 3D plot."""
+        """Get corresponding click location in the 3D plot.
+
+        Returns
+        -------
+        tuple
+            Three item tuple with the 3D picked position.
+
+        """
         if self.click_position is None:
             self.store_click_position()
         picker = _vtk.vtkWorldPointPicker()
@@ -588,7 +615,14 @@ class PickingHelper:
         return picker.GetPickPosition()
 
     def pick_mouse_position(self):
-        """Get corresponding mouse location in the 3D plot."""
+        """Get corresponding mouse location in the 3D plot.
+
+        Returns
+        -------
+        tuple
+            Three item tuple with the 3D picked position.
+
+        """
         if self.mouse_position is None:
             self.store_mouse_position()
         picker = _vtk.vtkWorldPointPicker()
@@ -612,12 +646,18 @@ class PickingHelper:
         the picked point in the scene. The callback will be passed the
         point in 3D space.
 
+        Parameters
+        ----------
+        callback : callable
+            Callback function to call immediately after right
+            clicking.
+
         """
 
         def _the_callback(*args):
             click_point = self.pick_mouse_position()
             self.fly_to(click_point)
-            if hasattr(callback, '__call__'):
+            if callable(callback):
                 try_callback(callback, click_point)
 
         self.track_click_position(callback=_the_callback, side="right")
