@@ -51,13 +51,13 @@ class RenderWindowInteractor():
         Parameters
         ----------
         key : str
-            The key to trigger the event
+            The key to trigger the event.
 
         callback : callable
-            A callable that takes no arguments
+            A callable that takes no arguments.
 
         """
-        if not hasattr(callback, '__call__'):
+        if not callable(callback):
             raise TypeError('callback must be callable.')
         self._key_press_event_callbacks[key].append(callback)
 
@@ -110,7 +110,7 @@ class RenderWindowInteractor():
             The side of the mouse for the button to track (left or
             right).  Default is left. Also accepts ``'r'`` or ``'l'``.
 
-        viewport: bool, optional
+        viewport : bool, optional
             If ``True``, uses the normalized viewport coordinate
             system (values between 0.0 and 1.0 and support for HiDPI)
             when passing the click position to the callback.
@@ -126,7 +126,7 @@ class RenderWindowInteractor():
 
         def _click_callback(obj, event):
             self._plotter.store_click_position()
-            if hasattr(callback, '__call__'):
+            if callable(callback):
                 if viewport:
                     callback(self._plotter.click_position)
                 else:
@@ -160,54 +160,107 @@ class RenderWindowInteractor():
         if self._style_class is None:
             # We need an actually custom style to handle button up events
             self._style_class = _style_factory(self._style)(self)
-        return self.interactor.SetInteractorStyle(self._style_class)
+        self.interactor.SetInteractorStyle(self._style_class)
 
     def enable_trackball_style(self):
-        """Set the interactive style to trackball camera.
+        """Set the interactive style to Trackball Camera.
 
-        The trackball camera is the default interactor style.
+        The trackball camera is the default interactor style. Moving
+        the mouse moves the camera around, leaving the scene intact.
+
+        For a 3-button mouse, the left button is for rotation, the
+        right button for zooming, the middle button for panning, and
+        ctrl + left button for spinning the view around the vewing
+        axis of the camera.  Alternatively, ctrl + shift + left button
+        or mouse wheel zooms, and shift + left button pans.
+
+        Examples
+        --------
+        Create a simple scene with a plotter that has the Trackball
+        Camera interactive style (which is also the default):
+
+        >>> import pyvista as pv
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(pv.Cube(center=(1, 0, 0)))
+        >>> _ = plotter.add_mesh(pv.Cube(center=(0, 1, 0)))
+        >>> plotter.show_axes()
+        >>> plotter.enable_trackball_style()
+        >>> plotter.show()  # doctest:+SKIP
 
         """
         self._style = 'TrackballCamera'
         self._style_class = None
-        return self.update_style()
+        self.update_style()
 
     def enable_trackball_actor_style(self):
-        """Set the interactive style to trackball actor.
+        """Set the interactive style to Trackball Actor.
 
-        This allows to rotate actors around the scene.
+        This allows to rotate actors around the scene. The controls
+        are similar to the default Trackball Camera style, but
+        movements transform specific objects under the mouse cursor.
+
+        For a 3-button mouse, the left button is for rotation, the
+        right button for zooming, the middle button for panning, and
+        ctrl + left button for spinning objects around the axis
+        connecting the camera with the their center.  Alternatively,
+        shift + left button pans.
+
+        Examples
+        --------
+        Create a simple scene with a plotter that has the Trackball
+        Actor interactive style:
+
+        >>> import pyvista as pv
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(pv.Cube(center=(1, 0, 0)))
+        >>> _ = plotter.add_mesh(pv.Cube(center=(0, 1, 0)))
+        >>> plotter.show_axes()
+        >>> plotter.enable_trackball_actor_style()
+        >>> plotter.show()  # doctest:+SKIP
 
         """
         self._style = 'TrackballActor'
         self._style_class = None
-        return self.update_style()
+        self.update_style()
 
     def enable_image_style(self):
-        """Set the interactive style to image.
+        """Set the interactive style to Image.
 
         Controls:
          - Left Mouse button triggers window level events
          - CTRL Left Mouse spins the camera around its view plane normal
          - SHIFT Left Mouse pans the camera
-         - CTRL SHIFT Left Mouse dollys (a positional zoom) the camera
+         - CTRL SHIFT Left Mouse dollies (a positional zoom) the camera
          - Middle mouse button pans the camera
-         - Right mouse button dollys the camera.
+         - Right mouse button dollies the camera
          - SHIFT Right Mouse triggers pick events
 
+        Examples
+        --------
+        Create a simple scene with a plotter that has the Image
+        interactive style:
+
+        >>> import pyvista as pv
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(pv.Cube(center=(1, 0, 0)))
+        >>> _ = plotter.add_mesh(pv.Cube(center=(0, 1, 0)))
+        >>> plotter.show_axes()
+        >>> plotter.enable_image_style()
+        >>> plotter.show()  # doctest:+SKIP
+
         """
         self._style = 'Image'
         self._style_class = None
-        return self.update_style()
+        self.update_style()
 
     def enable_joystick_style(self):
-        """Set the interactive style to joystick.
+        """Set the interactive style to Joystick Camera.
 
         It allows the user to move (rotate, pan, etc.) the camera, the
         point of view for the scene.  The position of the mouse
         relative to the center of the scene determines the speed at
-        which the camera moves, and the speed of the mouse movement
-        determines the acceleration of the camera, so the camera
-        continues to move even if the mouse if not moving.
+        which the camera moves, so the camera continues to move even
+        if the mouse if not moving.
 
         For a 3-button mouse, the left button is for rotation, the
         right button for zooming, the middle button for panning, and
@@ -215,71 +268,256 @@ class RenderWindowInteractor():
         ctrl + shift + left button is for zooming, and shift + left
         button is for panning.)
 
+        Examples
+        --------
+        Create a simple scene with a plotter that has the Joystick
+        Camera interactive style:
+
+        >>> import pyvista as pv
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(pv.Cube(center=(1, 0, 0)))
+        >>> _ = plotter.add_mesh(pv.Cube(center=(0, 1, 0)))
+        >>> plotter.show_axes()
+        >>> plotter.enable_joystick_style()
+        >>> plotter.show()  # doctest:+SKIP
+
         """
         self._style = 'JoystickCamera'
         self._style_class = None
-        return self.update_style()
+        self.update_style()
+
+    def enable_joystick_actor_style(self):
+        """Set the interactive style to Joystick Actor.
+
+        Similar to the Joystick Camera interaction style, however
+        in case of the Joystick Actor style the objects in the scene
+        rather than the camera can be moved (rotated, panned, etc.).
+        The position of the mouse relative to the center of the object
+        determines the speed at which the object moves, so the object
+        continues to move even if the mouse is not moving.
+
+        For a 3-button mouse, the left button is for rotation, the
+        right button for zooming, the middle button for panning, and
+        ctrl + left button for spinning.  (With fewer mouse buttons,
+        ctrl + shift + left button is for zooming, and shift + left
+        button is for panning.)
+
+        Examples
+        --------
+        Create a simple scene with a plotter that has the Joystick
+        Actor interactive style:
+
+        >>> import pyvista as pv
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(pv.Cube(center=(1, 0, 0)))
+        >>> _ = plotter.add_mesh(pv.Cube(center=(0, 1, 0)))
+        >>> plotter.show_axes()
+        >>> plotter.enable_joystick_actor_style()
+        >>> plotter.show()  # doctest:+SKIP
+
+        """
+        self._style = 'JoystickActor'
+        self._style_class = None
+        self.update_style()
 
     def enable_zoom_style(self):
-        """Set the interactive style to rubber band zoom.
+        """Set the interactive style to Rubber Band Zoom.
 
         This interactor style allows the user to draw a rectangle in
         the render window using the left mouse button.  When the mouse
         button is released, the current camera zooms by an amount
         determined from the shorter side of the drawn rectangle.
 
+        Examples
+        --------
+        Create a simple scene with a plotter that has the Rubber Band
+        Zoom interactive style:
+
+        >>> import pyvista as pv
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(pv.Cube(center=(1, 0, 0)))
+        >>> _ = plotter.add_mesh(pv.Cube(center=(0, 1, 0)))
+        >>> plotter.show_axes()
+        >>> plotter.enable_zoom_style()
+        >>> plotter.show()  # doctest:+SKIP
+
         """
         self._style = 'RubberBandZoom'
         self._style_class = None
-        return self.update_style()
+        self.update_style()
 
-    def enable_terrain_style(self):
-        """Set the interactive style to terrain.
+    def enable_terrain_style(self, mouse_wheel_zooms=False, shift_pans=False):
+        """Set the interactive style to Terrain.
 
-        Used to manipulate a camera which is viewing a scene with a natural
-        view up, e.g., terrain. The camera in such a scene is manipulated by
-        specifying azimuth (angle around the view up vector) and elevation
-        (the angle from the horizon).
+        Used to manipulate a camera which is viewing a scene with a
+        natural view up, e.g., terrain. The camera in such a scene is
+        manipulated by specifying azimuth (angle around the view up
+        vector) and elevation (the angle from the horizon). Similar to
+        the default Trackball Camera style and in contrast to the
+        Joystick Camera style, movements of the mouse translate to
+        movements of the camera.
+
+        Left mouse click rotates the camera around the focal point
+        using both elevation and azimuth invocations on the camera.
+        Left mouse motion in the horizontal direction results in
+        azimuth motion; left mouse motion in the vertical direction
+        results in elevation motion. Therefore, diagonal motion results
+        in a combination of azimuth and elevation. (If the shift key is
+        held during motion, then only one of elevation or azimuth is
+        invoked, depending on the whether the mouse motion is primarily
+        horizontal or vertical.) Middle mouse button pans the camera
+        across the scene (again the shift key has a similar effect on
+        limiting the motion to the vertical or horizontal direction.
+        The right mouse is used to dolly towards or away from the focal
+        point (zoom in or out). Panning and zooming behavior can be
+        overridden to match the Trackball Camera style.
+
+        The class also supports some keypress events. The ``r`` key
+        resets the camera. The ``e`` key invokes the exit callback
+        and closes the plotter. The ``f`` key sets a new
+        camera focal point and flies towards that point. The ``u``
+        key invokes the user event. The ``3`` key toggles between
+        stereo and non-stero mode. The ``l`` key toggles on/off
+        latitude/longitude markers that can be used to estimate/control
+        position.
+
+        Parameters
+        ----------
+        mouse_wheel_zooms : bool, optional
+            Whether to use the mouse wheel for zooming. By default
+            zooming can be performed with right click and drag.
+
+        shift_pans : bool, optional
+            Whether shift + left mouse button pans the scene. By default
+            shift + left mouse button rotates the view restricted to
+            only horizontal or vertical movements, and panning is done
+            holding down the middle mouse button.
+
+        Examples
+        --------
+        Create a simple scene with a plotter that has the Terrain
+        interactive style:
+
+        >>> import pyvista as pv
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(pv.Cube(center=(1, 0, 0)))
+        >>> _ = plotter.add_mesh(pv.Cube(center=(0, 1, 0)))
+        >>> plotter.show_axes()
+        >>> plotter.enable_terrain_style()
+        >>> plotter.show()  # doctest:+SKIP
+
+        Use controls that are closer to the default style:
+
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(pv.Cube(center=(1, 0, 0)))
+        >>> _ = plotter.add_mesh(pv.Cube(center=(0, 1, 0)))
+        >>> plotter.show_axes()
+        >>> plotter.enable_terrain_style(mouse_wheel_zooms=True,
+        ...                              shift_pans=True)
+        >>> plotter.show()  # doctest:+SKIP
 
         """
         self._style = 'Terrain'
         self._style_class = None
-        return self.update_style()
+        self.update_style()
+
+        if mouse_wheel_zooms:
+            def wheel_zoom_callback(obj, event):  # pragma: no cover
+                """Zoom in or out on mouse wheel roll."""
+                if event == 'MouseWheelForwardEvent':
+                    # zoom in
+                    zoom_factor = 1.1
+                elif event == 'MouseWheelBackwardEvent':
+                    # zoom out
+                    zoom_factor = 1/1.1
+                self._plotter.camera.zoom(zoom_factor)
+                self._plotter.render()
+            callback = partial(try_callback, wheel_zoom_callback)
+
+            for event in 'MouseWheelForwardEvent', 'MouseWheelBackwardEvent':
+                self._style_class.AddObserver(event, callback)
+
+        if shift_pans:
+            def pan_on_shift_callback(obj, event):  # pragma: no cover
+                """Trigger left mouse panning if shift is pressed."""
+                if event == 'LeftButtonPressEvent':
+                    if self.interactor.GetShiftKey():
+                        self._style_class.StartPan()
+                    self._style_class.OnLeftButtonDown()
+                elif event == 'LeftButtonReleaseEvent':
+                    # always stop panning on release
+                    self._style_class.EndPan()
+                    self._style_class.OnLeftButtonUp()
+            callback = partial(try_callback, pan_on_shift_callback)
+
+            for event in 'LeftButtonPressEvent', 'LeftButtonReleaseEvent':
+                self._style_class.AddObserver(event, callback)
 
     def enable_rubber_band_style(self):
-        """Set the interactive style to rubber band picking.
+        """Set the interactive style to Rubber Band Picking.
 
-        This interactor style allows the user to draw a rectangle in the render
-        window by hitting 'r' and then using the left mouse button.
-        When the mouse button is released, the attached picker operates on the
-        pixel in the center of the selection rectangle. If the picker happens to
-        be a vtkAreaPicker it will operate on the entire selection rectangle.
-        When the 'p' key is hit the above pick operation occurs on a 1x1
-        rectangle. In other respects it behaves the same as its parent class.
+        This interactor style allows the user to draw a rectangle in
+        the render window by hitting ``r`` and then using the left
+        mouse button. When the mouse button is released, the attached
+        picker operates on the pixel in the center of the selection
+        rectangle. If the picker happens to be a ``vtkAreaPicker``
+        it will operate on the entire selection rectangle. When the
+        ``p`` key is hit the above pick operation occurs on a 1x1
+        rectangle. In other respects it behaves the same as the
+        Trackball Camera style.
+
+        Examples
+        --------
+        Create a simple scene with a plotter that has the Rubber Band
+        Pick interactive style:
+
+        >>> import pyvista as pv
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(pv.Cube(center=(1, 0, 0)))
+        >>> _ = plotter.add_mesh(pv.Cube(center=(0, 1, 0)))
+        >>> plotter.show_axes()
+        >>> plotter.enable_rubber_band_style()
+        >>> plotter.show()  # doctest:+SKIP
 
         """
         self._style = 'RubberBandPick'
         self._style_class = None
-        return self.update_style()
+        self.update_style()
 
     def enable_rubber_band_2d_style(self):
-        """Set the interactive style to rubber band 2d.
+        """Set the interactive style to Rubber Band 2D.
 
-        Camera rotation is not allowed with this interactor
+        Camera rotation is not enabled with this interactor
         style. Zooming affects the camera's parallel scale only, and
         assumes that the camera is in parallel projection mode. The
-        style also allows draws a rubber band using the left
-        button. All camera changes invoke StartInteractionEvent when
-        the button is pressed, InteractionEvent when the mouse (or
-        wheel) is moved, and EndInteractionEvent when the button is
-        released. The bindings are as follows: Left mouse - Select
-        (invokes a SelectionChangedEvent). Right mouse - Zoom.  Middle
-        mouse - Pan. Scroll wheel - Zoom.
+        style also allows to draw a rubber band using the left mouse
+        button. All camera changes invoke ``StartInteractionEvent`` when
+        the button is pressed, ``InteractionEvent`` when the mouse (or
+        wheel) is moved, and ``EndInteractionEvent`` when the button is
+        released. The bindings are as follows:
+
+          * Left mouse: Select (invokes a ``SelectionChangedEvent``).
+          * Right mouse: Zoom.
+          * Middle mouse: Pan.
+          * Scroll wheel: Zoom.
+
+        Examples
+        --------
+        Create a simple scene with a plotter that has the Rubber Band
+        2D interactive style:
+
+        >>> import pyvista as pv
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(pv.Cube(center=(1, 0, 0)))
+        >>> _ = plotter.add_mesh(pv.Cube(center=(0, 1, 0)))
+        >>> plotter.show_axes()
+        >>> plotter.enable_rubber_band_2d_style()
+        >>> plotter.show()  # doctest:+SKIP
 
         """
         self._style = 'RubberBand2D'
         self._style_class = None
-        return self.update_style()
+        self.update_style()
 
     def _simulate_keypress(self, key):  # pragma: no cover
         """Simulate a keypress."""
@@ -328,19 +566,44 @@ class RenderWindowInteractor():
         self.interactor.MouseMoveEvent()
 
     def get_event_position(self):
-        """Get the event position."""
+        """Get the event position.
+
+        Returns
+        -------
+        tuple
+            The ``(x, y)`` coordinate position.
+
+        """
         return self.interactor.GetEventPosition()
 
     def get_interactor_style(self):
-        """Get the interactor style."""
+        """Get the interactor style.
+
+        Returns
+        -------
+        vtk.vtkInteractorStyle
+            VTK interactor style.
+        """
         return self.interactor.GetInteractorStyle()
 
     def get_desired_update_rate(self):
-        """Get the desired update rate."""
+        """Get the desired update rate.
+
+        Returns
+        -------
+        float
+            Desired update rate.
+        """
         return self.interactor.GetDesiredUpdateRate()
 
     def create_repeating_timer(self, stime):
-        """Create a repeating timer."""
+        """Create a repeating timer.
+
+        Returns
+        -------
+        int
+            Timer ID.
+        """
         timer_id = self.interactor.CreateRepeatingTimer(stime)
         if hasattr(self.interactor, 'ProcessEvents'):
             self.process_events()
@@ -375,7 +638,13 @@ class RenderWindowInteractor():
         return self.interactor.GetInitialized()
 
     def get_picker(self):
-        """Get the piccker."""
+        """Get the picker.
+
+        Returns
+        -------
+        vtk.vtkAbstractPicker
+            VTK picker.
+        """
         return self.interactor.GetPicker()
 
     def set_picker(self, picker):
