@@ -5,6 +5,8 @@ from math import pi
 
 import pyvista
 from pyvista import _vtk
+from pyvista.utilities.errors import check_valid_vector
+import numpy as np
 from .geometric_objects import translate
 
 
@@ -22,7 +24,7 @@ def Spline(points, n_points=None):
 
     Returns
     -------
-    spline : pyvista.PolyData
+    pyvista.PolyData
         Line mesh of spline.
 
     Examples
@@ -38,6 +40,7 @@ def Spline(points, n_points=None):
     >>> y = r * np.cos(theta)
     >>> points = np.column_stack((x, y, z))
     >>> spline = pv.Spline(points, 1000)
+    >>> spline.plot(render_lines_as_tubes=True, line_width=10, show_scalar_bar=False)
 
     """
     spline_function = _vtk.vtkParametricSpline()
@@ -53,6 +56,103 @@ def Spline(points, n_points=None):
     return spline.compute_arc_length()
 
 
+def KochanekSpline(points, tension=None, bias=None, continuity=None, n_points=None):
+    """Create a Kochanek spline from points.
+
+    Parameters
+    ----------
+    points : sequence
+        Array of points to build a Kochanek spline out of.  Array must
+        be 3D and directionally ordered.
+
+    tension : sequence, optional
+        Changes the length of the tangent vector.  Defaults to ``[0.0,
+        0.0, 0.0]``.
+
+    bias : sequence, optional
+        Primarily changes the direction of the tangent vector.
+        Defaults to ``[0.0, 0.0, 0.0]``.
+
+    continuity : sequence, optional
+        Changes the sharpness in change between tangents.  Defaults to
+        ``[0.0, 0.0, 0.0]``.
+
+    n_points : int, optional
+        Number of points on the spline.  Defaults to the number of
+        points in ``points``.
+
+    Returns
+    -------
+    pyvista.PolyData
+        Kochanek spline.
+
+    Examples
+    --------
+    Construct a Kochanek spline.
+
+    >>> import numpy as np
+    >>> import pyvista as pv
+    >>> theta = np.linspace(-4 * np.pi, 4 * np.pi, 100)
+    >>> z = np.linspace(-2, 2, 100)
+    >>> r = z ** 2 + 1
+    >>> x = r * np.sin(theta)
+    >>> y = r * np.cos(theta)
+    >>> points = np.column_stack((x, y, z))
+    >>> kochanek_spline = pv.KochanekSpline(points, n_points=6)
+    >>> kochanek_spline.plot(line_width=4, color="k")
+
+    See :ref:`create_kochanek_spline_example` for an additional example.
+
+    """
+    if tension is None:
+        tension = np.array([0.0, 0.0, 0.0])
+    check_valid_vector(tension, "tension")
+    if not np.all(np.abs(tension) <= 1.0):
+        raise ValueError("The absolute value of all values of the tension array elements must be <= 1.0 ")
+
+    if bias is None:
+        bias = np.array([0.0, 0.0, 0.0])
+    check_valid_vector(bias, "bias")
+    if not np.all(np.abs(bias) <= 1.0):
+        raise ValueError("The absolute value of all values of the bias array elements must be <= 1.0 ")
+
+    if continuity is None:
+        continuity = np.array([0.0, 0.0, 0.0])
+    check_valid_vector(continuity, "continuity")
+    if not np.all(np.abs(continuity) <= 1.0):
+        raise ValueError(
+            "The absolute value of all values continuity array elements must be <= 1.0 "
+        )
+
+    spline_function = _vtk.vtkParametricSpline()
+    spline_function.SetPoints(pyvista.vtk_points(points, False))
+
+    # set Kochanek spline for each direction
+    xspline = _vtk.vtkKochanekSpline()
+    yspline = _vtk.vtkKochanekSpline()
+    zspline = _vtk.vtkKochanekSpline()
+    xspline.SetDefaultBias(bias[0])
+    yspline.SetDefaultBias(bias[1])
+    zspline.SetDefaultBias(bias[2])
+    xspline.SetDefaultTension(tension[0])
+    yspline.SetDefaultTension(tension[1])
+    zspline.SetDefaultTension(tension[2])
+    xspline.SetDefaultContinuity(continuity[0])
+    yspline.SetDefaultContinuity(continuity[1])
+    zspline.SetDefaultContinuity(continuity[2])
+    spline_function.SetXSpline(xspline)
+    spline_function.SetYSpline(yspline)
+    spline_function.SetZSpline(zspline)
+
+    # get interpolation density
+    u_res = n_points
+    if u_res is None:
+        u_res = points.shape[0]
+
+    u_res -= 1
+    spline = surface_from_para(spline_function, u_res)
+    return spline.compute_arc_length()
+
 def ParametricBohemianDome(a=None, **kwargs):
     """Generate a Bohemian dome surface.
 
@@ -61,9 +161,12 @@ def ParametricBohemianDome(a=None, **kwargs):
     a : float, optional
         Bohemian dome surface parameter.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
+    pyvista.PolyData
         ParametricBohemianDome surface.
 
     Examples
@@ -72,7 +175,7 @@ def ParametricBohemianDome(a=None, **kwargs):
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricBohemianDome()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricBohemianDome()
@@ -91,9 +194,14 @@ def ParametricBohemianDome(a=None, **kwargs):
 def ParametricBour(**kwargs):
     """Generate Bour's minimal surface.
 
+    Parameters
+    ----------
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
+    pyvista.PolyData
         ParametricBour surface.
 
     Examples
@@ -102,7 +210,7 @@ def ParametricBour(**kwargs):
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricBour()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricBour()
@@ -131,9 +239,12 @@ def ParametricBoy(zscale=None, **kwargs):
     zscale : float, optional
         The scale factor for the z-coordinate.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
+    pyvista.PolyData
         ParametricBoy surface.
 
     Examples
@@ -142,7 +253,7 @@ def ParametricBoy(zscale=None, **kwargs):
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricBoy()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricBoy()
@@ -165,9 +276,14 @@ def ParametricCatalanMinimal(**kwargs):
     parametrically. This minimal surface contains the cycloid as a
     geodesic.
 
+    Parameters
+    ----------
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
+    pyvista.PolyData
         ParametricCatalanMinimal surface.
 
     Example
@@ -176,7 +292,7 @@ def ParametricCatalanMinimal(**kwargs):
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricCatalanMinimal()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricCatalanMinimal()
@@ -218,9 +334,12 @@ def ParametricConicSpiral(a=None, b=None, c=None, n=None, **kwargs):
         See the definition in Parametric surfaces referred to above.
         Default is 2.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
+    pyvista.PolyData
         ParametricConicSpiral surface
 
     Examples
@@ -229,7 +348,7 @@ def ParametricConicSpiral(a=None, b=None, c=None, n=None, **kwargs):
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricConicSpiral()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricConicSpiral()
@@ -261,9 +380,14 @@ def ParametricCrossCap(**kwargs):
     self-intersecting single-sided surface.  This is one possible
     image of a projective plane in three-space.
 
+    Parameters
+    ----------
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
+    pyvista.PolyData
         ParametricCrossCap surface.
 
     Examples
@@ -272,7 +396,7 @@ def ParametricCrossCap(**kwargs):
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricCrossCap()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricCrossCap()
@@ -295,19 +419,20 @@ def ParametricDini(a=None, b=None, **kwargs):
     Parameters
     ----------
     a : float, optional
-        The scale factor.
-        See the definition in Parametric surfaces referred to above.
-        Default is 1.
+        The scale factor.  See the definition in Parametric surfaces
+        referred to above.  Default is 1.
 
     b : float, optional
-        The scale factor.
-        See the definition in Parametric surfaces referred to above.
-        Default is 0.2
+        The scale factor.  See the definition in Parametric surfaces
+        referred to above.  Default is 0.2.
+
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
 
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricDini surface
+    pyvista.PolyData
+        ParametricDini surface.
 
     Examples
     --------
@@ -315,7 +440,7 @@ def ParametricDini(a=None, b=None, **kwargs):
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricDini()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricDini()
@@ -355,10 +480,14 @@ def ParametricEllipsoid(xradius=None, yradius=None, zradius=None,
     zradius : float, optional
         The scaling factor for the z-axis. Default is 1.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` and :func:`parametric_keywords`
+        for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricEllipsoid surface
+    pyvista.PolyData
+        ParametricEllipsoid surface.
 
     Examples
     --------
@@ -366,7 +495,7 @@ def ParametricEllipsoid(xradius=None, yradius=None, zradius=None,
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricEllipsoid()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricEllipsoid()
@@ -405,18 +534,23 @@ def ParametricEnneper(**kwargs):
     is a self-intersecting minimal surface possessing constant
     negative Gaussian curvature.
 
+    Parameters
+    ----------
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricEnneper surface
+    pyvista.PolyData
+        ParametricEnneper surface.
 
     Examples
     --------
-    Create a ParametricEnneper mesh
+    Create a ParametricEnneper mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricEnneper()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricEnneper()
@@ -441,10 +575,12 @@ def ParametricFigure8Klein(radius=None, **kwargs):
     ----------
     radius : float, optional
         The radius of the bottle. Default is 1.
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
 
     Returns
     -------
-    surf : pyvista.PolyData
+    pyvista.PolyData
         ParametricFigure8Klein surface.
 
     Examples
@@ -453,7 +589,7 @@ def ParametricFigure8Klein(radius=None, **kwargs):
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricFigure8Klein()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricFigure8Klein()
@@ -472,10 +608,15 @@ def ParametricFigure8Klein(radius=None, **kwargs):
 def ParametricHenneberg(**kwargs):
     """Generate Henneberg's minimal surface.
 
+    Parameters
+    ----------
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricHenneberg surface
+    pyvista.PolyData
+        ParametricHenneberg surface.
 
     Examples
     --------
@@ -483,7 +624,7 @@ def ParametricHenneberg(**kwargs):
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricHenneberg()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricHenneberg()
@@ -505,10 +646,15 @@ def ParametricKlein(**kwargs):
     surface.  It is unrealisable in 3 dimensions without intersecting
     surfaces.
 
+    Parameters
+    ----------
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricKlein surface
+    pyvista.PolyData
+        ParametricKlein surface.
 
     Examples
     --------
@@ -516,7 +662,7 @@ def ParametricKlein(**kwargs):
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricKlein()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricKlein()
@@ -539,24 +685,27 @@ def ParametricKuen(deltav0=None, **kwargs):
     Parameters
     ----------
     deltav0 : float, optional
-        The value to use when V == 0.
+        The value to use when ``V == 0``.
         Default is 0.05, giving the best appearance with the default settings.
         Setting it to a value less than 0.05 extrapolates the surface
         towards a pole in the -z direction.
         Setting it to 0 retains the pole whose z-value is -inf.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricKuen surface
+    pyvista.PolyData
+        ParametricKuen surface.
 
     Examples
     --------
-    Create a ParametricKuen mesh
+    Create a ParametricKuen mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricKuen()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricKuen()
@@ -580,18 +729,21 @@ def ParametricMobius(radius=None, **kwargs):
     radius : float, optional
         The radius of the Mobius strip. Default is 1.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricMobius surface
+    pyvista.PolyData
+        ParametricMobius surface.
 
     Examples
     --------
-    Create a ParametricMobius mesh
+    Create a ParametricMobius mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricMobius()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricMobius()
@@ -610,29 +762,31 @@ def ParametricMobius(radius=None, **kwargs):
 def ParametricPluckerConoid(n=None, **kwargs):
     """Generate Plucker's conoid surface.
 
-    ParametricPluckerConoid generates Plucker's conoid surface parametrically.
-    Plucker's conoid is a ruled surface, named after Julius Plucker. It is
-    possible to set the number of folds in this class via the parameter 'N'.
+    ParametricPluckerConoid generates Plucker's conoid surface
+    parametrically.  Plucker's conoid is a ruled surface, named after
+    Julius Plucker. It is possible to set the number of folds in this
+    class via the parameter 'n'.
 
     Parameters
     ----------
     n : int, optional
         This is the number of folds in the conoid.
 
-    vtkGetMacro(N, int);
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
 
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricPluckerConoid surface
+    pyvista.PolyData
+        ParametricPluckerConoid surface.
 
     Examples
     --------
-    Create a ParametricPluckerConoid mesh
+    Create a ParametricPluckerConoid mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricPluckerConoid()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricPluckerConoid()
@@ -656,18 +810,23 @@ def ParametricPseudosphere(**kwargs):
     tractrix about it's asymptote, and is a surface of constant
     negative Gaussian curvature.
 
+    Parameters
+    ----------
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricPseudosphere surface
+    pyvista.PolyData
+        ParametricPseudosphere surface.
 
     Examples
     --------
-    Create a ParametricPseudosphere mesh
+    Create a ParametricPseudosphere mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricPseudosphere()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricPseudosphere()
@@ -731,18 +890,21 @@ def ParametricRandomHills(numberofhills=None, hillxvariance=None,
         The scaling factor for the amplitude.
         Default is 13.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricRandomHills surface
+    pyvista.PolyData
+        ParametricRandomHills surface.
 
     Examples
     --------
-    Create a ParametricRandomHills mesh
+    Create a ParametricRandomHills mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricRandomHills()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricRandomHills()
@@ -787,18 +949,21 @@ def ParametricRoman(radius=None, **kwargs):
     radius : float, optional
         The radius. Default is 1.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricRoman surface
+    pyvista.PolyData
+        ParametricRoman surface.
 
     Examples
     --------
-    Create a ParametricRoman mesh
+    Create a ParametricRoman mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricRoman()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricRoman()
@@ -840,18 +1005,21 @@ def ParametricSuperEllipsoid(xradius=None, yradius=None, zradius=None,
     n2 : float, optional
         The "squareness" parameter in the x-y plane. Default is 1.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricSuperEllipsoid surface
+    pyvista.PolyData
+        ParametricSuperEllipsoid surface.
 
     Examples
     --------
-    Create a ParametricSuperEllipsoid mesh
+    Create a ParametricSuperEllipsoid mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricSuperEllipsoid()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricSuperEllipsoid()
@@ -897,11 +1065,11 @@ def ParametricSuperToroid(ringradius=None, crosssectionradius=None,
     ----------
     ringradius : float, optional
         The radius from the center to the middle of the ring of the
-      supertoroid. Default is 1.
+        supertoroid. Default is 1.
 
     crosssectionradius : float, optional
         The radius of the cross section of ring of the supertoroid.
-      Default = 0.5.
+        Default = 0.5.
 
     xradius : float, optional
         The scaling factor for the x-axis. Default is 1.
@@ -918,18 +1086,21 @@ def ParametricSuperToroid(ringradius=None, crosssectionradius=None,
     n2 : float, optional
         The shape of the cross section of the ring. Default is 1.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricSuperToroid surface
+    pyvista.PolyData
+        ParametricSuperToroid surface.
 
     Examples
     --------
-    Create a ParametricSuperToroid mesh
+    Create a ParametricSuperToroid mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricSuperToroid()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricSuperToroid()
@@ -975,18 +1146,21 @@ def ParametricTorus(ringradius=None, crosssectionradius=None, **kwargs):
     crosssectionradius : float, optional
         The radius of the cross section of ring of the torus. Default is 0.5.
 
+    **kwargs : dict, optional
+        See :func:`surface_from_para` for additional keyword arguments.
+
     Returns
     -------
-    surf : pyvista.PolyData
-        ParametricTorus surface
+    pyvista.PolyData
+        ParametricTorus surface.
 
     Examples
     --------
-    Create a ParametricTorus mesh
+    Create a ParametricTorus mesh.
 
     >>> import pyvista
     >>> mesh = pyvista.ParametricTorus()
-    >>> cpos = mesh.plot(color='w', smooth_shading=True)
+    >>> mesh.plot(color='w', smooth_shading=True)
 
     """
     parametric_function = _vtk.vtkParametricTorus()
@@ -1012,6 +1186,9 @@ def parametric_keywords(parametric_function, min_u=0, max_u=2*pi,
 
     Parameters
     ----------
+    parametric_function : vtk.vtkParametricFunction
+        Parametric function to generate mesh from.
+
     min_u : float, optional
         The minimum u-value.
 
@@ -1056,8 +1233,7 @@ def parametric_keywords(parametric_function, min_u=0, max_u=2*pi,
     parametric_function.SetClockwiseOrdering(clockwise)
 
 
-def surface_from_para(parametric_function, u_res=100, v_res=100,
-                      w_res=100):
+def surface_from_para(parametric_function, u_res=100, v_res=100, w_res=100):
     """Construct a mesh from a parametric function.
 
     Parameters
@@ -1074,6 +1250,11 @@ def surface_from_para(parametric_function, u_res=100, v_res=100,
     w_res : int, optional
         Resolution in the w direction.
 
+    Returns
+    -------
+    pyvista.PolyData
+        Surface from the parametric function.
+
     """
     # convert to a mesh
     para_source = _vtk.vtkParametricFunctionSource()
